@@ -117,6 +117,8 @@ static char *models[] =
 	"Intel\\(R\\) Core\\(TM\\)2 Duo CPU     P8600  @ [0-3]\\.[0-9]{2}GHz", "Core 2 Duo",
 	"Intel\\(R\\) Core\\(TM\\)2 Quad CPU    Q6600  @ [0-3]\\.[0-9]{2}GHz", "Core 2 Quad",
 	"Intel\\(R\\) Core\\(TM\\)2 Quad CPU    Q9550  @ [0-3]\\.[0-9]{2}GHz", "Core 2 Quad",
+	"Intel\\(R\\) Core\\(TM\\) i3-2100 CPU @ [0-3]\\.[0-9]{2}GHz", "Core i3",
+	"Intel\\(R\\) Core\\(TM\\) i3-4170 CPU @ [0-3]\\.[0-9]{2}GHz", "Core i3",
 	"Intel\\(R\\) Core\\(TM\\) i5-6600 CPU @ [0-3]\\.[0-9]{2}GHz", "Core i5",
 	"Intel\\(R\\) Core\\(TM\\) i5-[0-9]{3}0U CPU @ [0-2]\\.[0-9]{2}GHz", "Core i5",
 	"Intel\\(R\\) Core\\(TM\\) i7-6600U CPU @ [0-3]\\.[0-9]{2}GHz", "Core i7",
@@ -213,6 +215,8 @@ static char *models[] =
 	"Intel(R) Core(TM)2 Duo CPU     P8600  @ 2.40GHz", "Core 2 Duo",
 	"Intel(R) Core(TM)2 Quad CPU    Q6600  @ 2.40GHz", "Core 2 Quad",
 	"Intel(R) Core(TM)2 Quad CPU    Q9550  @ 2.83GHz", "Core 2 Quad",
+	"Intel(R) Core(TM) i3-2100 CPU @ 3.10GHz", "Core i3",
+	"Intel(R) Core(TM) i3-4170 CPU @ 3.70GHz", "Core i3",
 	"Intel(R) Core(TM) i5-4210U CPU @ 1.70GHz", "Core i5",
 	"Intel(R) Core(TM) i5-5300U CPU @ 2.30GHz", "Core i5",
 	"Intel(R) Core(TM) i5-6200U CPU @ 2.30GHz", "Core i5",
